import Vue from 'vue';
import Vuex from 'vuex';
import _ from 'lodash';
import config from '@frame/config';
const { pageSize = 10 } = config;

Vue.use(Vuex);
const api = {
  modules: `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/modules/create`,
  query: `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/modules/query`,
  fetch: id => `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/modules/fetch/${id}`,
  update: id => `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/modules/update/${id}`,
  delete: id => `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/modules/delete/${id}`,
};
export const state = () => ({});

export const mutations = {};

export const actions = {
  async moduleOperation({ state }, { type, data }) {
    let result;
    if (type === 'add') {
      let { info, site } = data;
      result = await this.$axios.$post(api.modules, info, { site: site });
    }
    if (type === 'list') {
      let { site } = data;
      const { page = 1, size = pageSize } = data;
      const skip = Math.max(0, (page - 1) * size);
      let options = { skip, limit: size };
      result = await this.$axios.$get(api.query, { site: site, ...options });
    }
    if (type === 'search') {
      let { id } = data;
      result = await this.$axios.$get(api.fetch(id));
    }
    if (type === 'update') {
      let { info, id } = data;
      result = await this.$axios.$post(api.update(id), info);
    }
    if (type === 'delete') {
      let { id } = data;
      result = await this.$axios.$post(api.delete(id));
    }
    return result;
  },
};
