import Vue from 'vue';
import Vuex from 'vuex';
import _ from 'lodash';
import config from '@frame/config';
const { pageSize = 10 } = config;

Vue.use(Vuex);
const api = {
  site: `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/site/create`,
  query: `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/site/query`,
  fetch: site => `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/site/fetch/${site}`,
  update: site => `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/site/update/${site}`,
  delete: site => `/adminapi${process.env.NODE_ENV === 'development' ? '' : ''}/site/delete/${site}`,
};
export const state = () => ({});

export const mutations = {};

export const actions = {
  async siteOperation({ state }, { type, data }) {
    let result;
    if (type === 'add') {
      let { info, site } = data;
      result = await this.$axios.$post(api.site, info, { site: site });
    }
    if (type === 'list') {
      let { site, column } = data;
      const { page = 1, size = pageSize } = data;
      const skip = Math.max(0, (page - 1) * size);
      let options = { skip, limit: size };
      result = await this.$axios.$get(api.query, { site: site, column: column, ...options });
    }
    if (type === 'search') {
      let { site } = data;
      result = await this.$axios.$get(api.fetch(site));
    }
    if (type === 'update') {
      let { info, site } = data;
      result = await this.$axios.$post(api.update(site), info);
    }
    if (type === 'delete') {
      let { site } = data;
      result = await this.$axios.$post(api.delete(site));
    }
    return result;
  },
};
